/**
 * Generated by Apache Royale Compiler from mx/core/DragSource.as
 * mx.core.DragSource
 *
 * @fileoverview
 *
 * @suppress {checkTypes|accessControls}
 */

goog.provide('mx.core.DragSource');
goog.require('XML');



/**
 *  Constructor.
 *  
 *  @langversion 3.0
 *  @playerversion Flash 9
 *  @playerversion AIR 1.1
 *  @productversion Royale 0.9.3
 * @constructor
 */
mx.core.DragSource = function() {
  
  this.mx_core_DragSource_dataHolder = {};
  this.mx_core_DragSource_formatHandlers = {};
  this.mx_core_DragSource__formats = [];
  ;
};


/**
 * @private
 * @type {Object}
 */
mx.core.DragSource.prototype.mx_core_DragSource_dataHolder;


/**
 * @private
 * @type {Object}
 */
mx.core.DragSource.prototype.mx_core_DragSource_formatHandlers;


/**
 * @private
 * @type {Array}
 */
mx.core.DragSource.prototype.mx_core_DragSource__formats;


/**
 *  Adds data and a corresponding format String to the drag source.
 *  This method does not return a value.
 * 
 *  @asparam data Object that specifies the drag data.
 *  This can be any object, such as a String, a DataProvider, and so on.
 *
 *  @asparam format String that specifies a label that describes
 *  the format for this data.
 *  
 *  @langversion 3.0
 *  @playerversion Flash 9
 *  @playerversion AIR 1.1
 *  @productversion Royale 0.9.3
 * @param {Object} data
 * @param {string} format
 */
mx.core.DragSource.prototype.addData = function(data, format) {
  this.mx_core_DragSource__formats.push(format);
  this.mx_core_DragSource_dataHolder[format] = data;
};


/**
 *  Adds a handler that is called when data
 *  for the specified format is requested. 
 *  This is useful when dragging large amounts of data.
 *  The handler is only called if the data is requested.
 *  This method does not return a value.
 *
 *  @asparam handler Function that specifies the handler
 *  called to request the data.
 *  This function must return the data in the specified format.
 *
 *  @asparam format String that specifies the format for this data.
 *  
 *  @langversion 3.0
 *  @playerversion Flash 9
 *  @playerversion AIR 1.1
 *  @productversion Royale 0.9.3
 * @param {Function} handler
 * @param {string} format
 */
mx.core.DragSource.prototype.addHandler = function(handler, format) {
  this.mx_core_DragSource__formats.push(format);
  this.mx_core_DragSource_formatHandlers[format] = handler;
};


/**
 *  Retrieves the data for the specified format.
 *  If the data was added with the <code>addData()</code> method,
 *  it is returned directly.
 *  If the data was added with the <code>addHandler()</code> method,
 *  the handler function is called to return the data.
 *
 *  @asparam format String that specifies a label that describes
 *  the format for the data to return. This string can be a custom value
 *  if you are creating a custom drop target with the <code>addData()</code> method. 
 *  <p>List-based controls have predefined values 
 *  for the <code>format</code> parameter. If the control that initiated the
 *  drag operation is a Tree, then the format is "treeItems" and the items
 *  implement the ITreeDataProvider interface. For all other List-based
 *  controls that have built-in drag and drop support, the format is "itemsByIndex" and the items
 *  implement the IDataProvider interface.</p>
 *
 *  @asreturn An Object
 *  containing the data in the requested format.
 *  If you drag multiple items, the returned value is an Array. 
 *  For a List-based control, the returned value is always an Array, 
 *  even if it contains a single item.
 *  
 *  @langversion 3.0
 *  @playerversion Flash 9
 *  @playerversion AIR 1.1
 *  @productversion Royale 0.9.3
 * @param {string} format
 * @return {Object}
 */
mx.core.DragSource.prototype.dataForFormat = function(format) {
  var /** @type {Object} */ data = this.mx_core_DragSource_dataHolder[format];
  if (data)
    return data;
  if (this.mx_core_DragSource_formatHandlers[format])
    return this.mx_core_DragSource_formatHandlers[format]();
  return null;
};


/**
 *  Returns <code>true</code> if the data source contains
 *  the requested format; otherwise, it returns <code>false</code>.
 *
 *  @asparam format String that specifies a label that describes the format 
 *  for the data. 
 *
 *  @asreturn <code>true</code> if the data source contains
 *  the requested format.
 *  
 *  @langversion 3.0
 *  @playerversion Flash 9
 *  @playerversion AIR 1.1
 *  @productversion Royale 0.9.3
 * @param {string} format
 * @return {boolean}
 */
mx.core.DragSource.prototype.hasFormat = function(format) {
  var /** @type {number} */ n = (this.mx_core_DragSource__formats.length) >> 0;
  for (var /** @type {number} */ i = 0; i < n; i++) {
    if (this.mx_core_DragSource__formats[i] == format)
      return true;
  }
  return false;
};


/**
 * @nocollapse
 * @export
 * @type {Array}
 */
mx.core.DragSource.prototype.formats;


mx.core.DragSource.prototype.get__formats = function() {
  return this.mx_core_DragSource__formats;
};


Object.defineProperties(mx.core.DragSource.prototype, /** @lends {mx.core.DragSource.prototype} */ {
/**
 * @type {Array}
 */
formats: {
get: mx.core.DragSource.prototype.get__formats}}
);


/**
 * Metadata
 *
 * @type {Object.<string, Array.<Object>>}
 */
mx.core.DragSource.prototype.ROYALE_CLASS_INFO = { names: [{ name: 'DragSource', qName: 'mx.core.DragSource', kind: 'class' }] };



/**
 * Reflection
 *
 * @return {Object.<string, Function>}
 */
mx.core.DragSource.prototype.ROYALE_REFLECTION_INFO = function () {
  return {
    accessors: function () {
      return {
        'formats': { type: 'Array', access: 'readonly', declaredBy: 'mx.core.DragSource'}
      };
    },
    methods: function () {
      return {
        'DragSource': { type: '', declaredBy: 'mx.core.DragSource'},
        'addData': { type: 'void', declaredBy: 'mx.core.DragSource', parameters: function () { return [ 'Object', false ,'String', false ]; }},
        'addHandler': { type: 'void', declaredBy: 'mx.core.DragSource', parameters: function () { return [ 'Function', false ,'String', false ]; }},
        'dataForFormat': { type: 'Object', declaredBy: 'mx.core.DragSource', parameters: function () { return [ 'String', false ]; }},
        'hasFormat': { type: 'Boolean', declaredBy: 'mx.core.DragSource', parameters: function () { return [ 'String', false ]; }}
      };
    }
  };
};
/**
 * @const
 * @type {number}
 */
mx.core.DragSource.prototype.ROYALE_COMPILE_FLAGS = 10;